@@ -5,7 +5,9 @@ import grpc
 
 
 class CancellableStreamThread:
-    def __init__(self, callback, create_stream, logger, attribute=None):
+    def __init__(
+        self, callback, create_stream, logger, attribute=None, ignore_unavailable=False
+    ):
         """
         Feeds data from the gRPC stream into the callback
         until the cancel method is called.
@@ -23,7 +25,9 @@ class CancellableStreamThread:
                 except grpc.RpcError as e:
                     if e.code() == grpc.StatusCode.CANCELLED:
                         return
-                    if logger:
+                    if logger and not (
+                        ignore_unavailable and e.code() == grpc.StatusCode.UNAVAILABLE
+                    ):
                         logger.warn("Error creating stream %s" % str(e))
                     if e.code() == grpc.StatusCode.UNAUTHENTICATED:
                         return
