@@ -100,6 +100,9 @@ class Client:
         self._teleop_heartbeat_callback_streams = (
             {}
         )  # type: Dict[Callable[..., None], CancellableStreamThread]
+        self._telemetry_listener_callback_streams = (
+            {}
+        )  # type: Dict[Callable[..., None], CancellableStreamThread]
 
         self._setup_agent_communication()
 
@@ -441,6 +444,44 @@ class Client:
             )
         )
 
+    def register_telemetry_listener_callback(
+        self,
+        f,  # type: Callable[[datapoint_pb2.Datapoint], None]
+        stream_filter=None,  # type: Optional[List[str]]
+    ):
+        # type : (...) -> None
+        """
+        Datapoints posted to the Formant agent whose "stream" value matches an element
+        of the given stream filter will be streamed into the provided callback.
+        If no stream filter is provided, datapoints from all streams
+        will be received.
+
+        :param f: A callback that will be called when a datapoint is posted
+            to the Formant agent
+        :param stream_filter: A list of stream names. The provided callback
+            is only called for datapoints whose stream name is in this list
+        """
+
+        def create_stream():
+            return self._get_telemetry_listener_stream(stream_filter=stream_filter)
+
+        self._telemetry_listener_callback_streams[f] = CancellableStreamThread(
+            f, create_stream, self.logger, ignore_unavailable=self.ignore_unavailable
+        )
+
+    def unregister_telemetry_listener_callback(
+        self, f  # type: Callable[[], None]
+    ):
+        # type : (...) -> None
+        """
+        Unregisters previously registered telemetry loopback callback.
+
+        :param f: The telemetry loopback callback to be unregistered
+        """
+        stream = self._telemetry_listener_callback_streams.pop(f, None)
+        if stream is not None:
+            stream.cancel()
+
     # Ingesting transform frames
 
     @handle_agent_exceptions
@@ -819,3 +860,8 @@ class Client:
         return self.agent_stub.GetTeleopHeartbeatStream(
             agent_pb2.GetTeleopHeartbeatStreamRequest()
         )
+
+    def _get_telemetry_listener_stream(self, stream_filter=None):
+        return self.agent_stub.GetTelemetryListenerStream(
+            agent_pb2.GetTelemetryListenerStreamRequest(stream_filter=stream_filter)
+        )
