@@ -41,7 +41,7 @@ RPC_ERROR_CODE_MAPPING = {
 
 def handle_agent_exceptions(func):
     @functools.wraps(func)
-    def _(*args, **kwargs):
+    def _handle_agent_exceptions_inner(*args, **kwargs):
         error = None
         try:
             return func(*args, **kwargs)
@@ -58,7 +58,7 @@ def handle_agent_exceptions(func):
 
         raise_exception(error, code)
 
-    return _
+    return _handle_agent_exceptions_inner
 
 
 def raise_exception(error, code):
